<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: index.php,v 1.18 2004/06/26 08:02:16 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2001 (c) Free Software Foundation
#
#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";

if ($_POST['group_id'])
   { 
   $group_id = $_POST['group_id']; 
   }
elseif ($_GET['group_id'])
   { 
   $group_id = $_GET['group_id']; 
   }
if ($_POST['category_id'])
   { 
   $category_id = $_POST['category_id']; 
   }
elseif ($_GET['category_id'])
   { 
   $category_id = $_GET['category_id']; 
   }
   
if ($group_id) 
{
  
  site_project_header(array('title'=>_('Project Help Wanted'),'group'=>$group_id,'toptab'=>'home'));
  
  # we get site-specific content
  utils_get_content("people/index_group");
  
  echo people_show_project_jobs($group_id);
  
} else if ($category_id) 
{

  echo $HTML->header(array('title'=>_('Projects looking for  '). people_get_category_name($category_id)));
  
  # we get site-specific content
  utils_get_content("people/index_cat");
  
  echo people_show_category_jobs($category_id);
  
} 
else
{

  echo $HTML->header(array('title'=>_('People')));
  
  # we get site-specific content
  utils_get_content("people/index");
  
  echo people_show_category_table();
  
}

site_project_footer(array());

?>
